<?php
/**
 * A generic command resolver class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2012 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class BaseCommandResolver extends BaseResolver {
	/**
	 * Validated command name
	 */
	private $commandName = '';

	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * Setter for command name
	 *
	 * @param	$commandName	Last validated command name
	 * @return	void
	 */
	protected final function setCommandName ($commandName) {
		$this->commandName = $commandName;
	}

	/**
	 * Getter for command name
	 *
	 * @return	$commandName	Last validated command name
	 */
	protected final function getCommandName () {
		return $this->commandName;
	}

	/**
	 * Checks whether the given command is valid
	 *
	 * @param	$commandName	The default command we shall execute
	 * @return	$isValid		Whether the given command is valid
	 * @throws	EmptyVariableException	Thrown if given command is not set
	 */
	public function isCommandValid ($commandName) {
		// By default nothing shall be valid
		$isValid = FALSE;

		// Is a command set?
		if (empty($commandName)) {
			// Then thrown an exception here
			throw new EmptyVariableException(array($this, 'commandName'), self::EXCEPTION_UNEXPECTED_EMPTY_STRING);
		} // END - if

		// Create the full class name
		$className = $this->getClassPrefix() . $this->convertToClassName($commandName) . 'Command';

		// Now, let us create the full name of the command class
		$this->setClassName($className);

		// Is this class already loaded?
		if (class_exists($this->getClassName())) {
			// This class does exist. :-)
			$isValid = TRUE;
		} // END - if

		// Set command name
		$this->setCommandName($commandName);

		// Return the result
		return $isValid;
	}
}

// [EOF]
?>
